@@ -467,6 +467,10 @@ void VideoWidget::start(bool evenIfNotYetStarted) {
     }
 }
 
+void VideoWidget::RecallStop() {
+    this->stop(this->savedStopCompletelyState);
+}
+
 void VideoWidget::stop(bool stopCompletely) {
     qDebug() << "VideoWidget::stop(): Called with stopCompletely = " << stopCompletely;
     if(focusing) {
@@ -474,6 +478,11 @@ void VideoWidget::stop(bool stopCompletely) {
         gst_photography_set_autofocus(GST_PHOTOGRAPHY(camera_src), FALSE);
         focusing = false;
         emit focusingValueChanged(false);
+
+        refocusTimer->stop(); // call this here too otherwise when we come back, we may be focusing again, and round again, ...
+        this->savedStopCompletelyState = stopCompletely;
+        QTimer::singleShot(2000, this, SLOT(RecallVideoWidgetStop()));
+        return;
     }
 
     if(pipeline != NULL) {
